summaryrefslogtreecommitdiffstats
diff options
context:
space:
mode:
-rw-r--r--gcc/ChangeLog21
-rw-r--r--gcc/ChangeLog.212
-rw-r--r--gcc/ChangeLog.42
-rw-r--r--gcc/ChangeLog.52
-rw-r--r--gcc/FSFChangeLog.104
-rw-r--r--gcc/FSFChangeLog.114
-rw-r--r--gcc/alias.c14
-rw-r--r--gcc/attribs.c2
-rw-r--r--gcc/caller-save.c2
-rw-r--r--gcc/calls.c12
-rw-r--r--gcc/cfg.c2
-rw-r--r--gcc/cfganal.c2
-rw-r--r--gcc/cfgcleanup.c2
-rw-r--r--gcc/cfgrtl.c2
-rw-r--r--gcc/config/alpha/alpha.c2
-rw-r--r--gcc/config/alpha/alpha.md10
-rw-r--r--gcc/config/c4x/c4x.h4
-rw-r--r--gcc/config/cris/cris.h6
-rw-r--r--gcc/config/cris/cris.md2
-rw-r--r--gcc/config/i370/i370.md14
-rw-r--r--gcc/config/i386/i386.c12
-rw-r--r--gcc/config/i386/i386.h2
-rw-r--r--gcc/config/i386/i386.md18
-rw-r--r--gcc/config/i386/xm-djgpp.h2
-rw-r--r--gcc/config/ia64/ia64.c2
-rw-r--r--gcc/config/m68hc11/m68hc11.c2
-rw-r--r--gcc/config/m68k/m68k.md4
-rw-r--r--gcc/config/mcore/mcore.h2
-rw-r--r--gcc/config/mmix/mmix.c2
-rw-r--r--gcc/config/ns32k/ns32k.h2
-rw-r--r--gcc/config/ns32k/ns32k.md2
-rw-r--r--gcc/config/rs6000/rs6000.c2
-rw-r--r--gcc/config/rs6000/sysv4.h2
-rw-r--r--gcc/config/sh/sh.md2
-rw-r--r--gcc/cppmacro.c2
-rw-r--r--gcc/fold-const.c2
-rw-r--r--gcc/ifcvt.c2
-rw-r--r--gcc/local-alloc.c2
-rw-r--r--gcc/profile.c2
-rw-r--r--gcc/sched-int.h2
-rw-r--r--gcc/toplev.c22
41 files changed, 113 insertions, 98 deletions
diff --git a/gcc/ChangeLog b/gcc/ChangeLog
index 33dc5abeaea..0c8e9f11937 100644
--- a/gcc/ChangeLog
+++ b/gcc/ChangeLog
@@ -1,3 +1,18 @@
+2001-11-04 Joseph S. Myers <jsm28@cam.ac.uk>
+
+ * ChangeLog.2, ChangeLog.4, ChangeLog.5, ChangeLog,
+ FSFChangeLog.10, FSFChangeLog.11, alias.c, attribs.c,
+ caller-save.c, calls.c, cfg.c, cfganal.c, cfgcleanup.c, cfgrtl.c,
+ cppmacro.c, fold-const.c, ifcvt.c, local-alloc.c, profile.c,
+ sched-int.h, toplev.c, config/alpha/alpha.c,
+ config/alpha/alpha.md, config/c4x/c4x.h, config/cris/cris.h,
+ config/cris/cris.md, config/i370/i370.md, config/i386/i386.c,
+ config/i386/i386.h, config/i386/i386.md, config/i386/xm-djgpp.h,
+ config/ia64/ia64.c, config/m68hc11/m68hc11.c, config/m68k/m68k.md,
+ config/mcore/mcore.h, config/mmix/mmix.c, config/ns32k/ns32k.h,
+ config/ns32k/ns32k.md, config/rs6000/rs6000.c,
+ config/rs6000/sysv4.h, config/sh/sh.md: Fix spelling errors.
+
2001-11-03 Kaveh R. Ghazi <ghazi@caip.rutgers.edu>
* Makefile.in (dbxout.o): Depend on function.h.
@@ -5351,7 +5366,7 @@ Wed Sep 5 17:28:49 CEST 2001 Jan Hubicka <jh@suse.cz>
* i386.c (ix86_expand_prologue): Set use_fast_prologue_epilogue
properly; Use current_function_calls_eh_return.
(ix86_expand_epilogue): Avoid dummy optimize_size tests;
- use leave to avoid depdendancy chain.
+ use leave to avoid dependency chain.
* local-alloc.c (update_equiv_regs): Use CFG to iterate over INSN stream;
get BB loop_depth instead of computing it from LOOP notes.
@@ -8544,7 +8559,7 @@ Sat Aug 4 13:51:36 CEST 2001 Jan Hubicka <jh@suse.cz>
(reload): Use it.
* flow.c (need_fake_edge_p): New function.
- (flow_call_edges_add): Fix handling of noreturn and sibbling calls;
+ (flow_call_edges_add): Fix handling of noreturn and sibling calls;
avoid call insn to be very last insn in the insn stream.
* profile.c (branch_prob): Call flow_call_edges_add instead of
@@ -11581,7 +11596,7 @@ Mon Jul 9 17:23:10 CEST 2001 Jan Hubicka <jh@suse.cz>
over by line number note.
* flow.c (try_simplify_condjump): Verify that the condjump
- is not always falling trought.
+ is not always falling through.
Re-install patch:
* flow.c (try_redirect_by_replacing_jump): Remove cc0 setter.
diff --git a/gcc/ChangeLog.2 b/gcc/ChangeLog.2
index 533a545e1f6..4aaeb0f32cb 100644
--- a/gcc/ChangeLog.2
+++ b/gcc/ChangeLog.2
@@ -4049,8 +4049,8 @@ Wed Oct 27 15:21:46 1999 Richard Henderson <rth@cygnus.com>
Wed Oct 27 12:33:40 1999 Mark Mitchell <mark@codesourcery.com>
- * rtl.h (note_stores): Add additional paramter.
- * rtlanal.c (reg_set_p_1): Take additional paramter.
+ * rtl.h (note_stores): Add additional parameter.
+ * rtlanal.c (reg_set_p_1): Take additional parameter.
(reg_set_last_1): Likewise.
(reg_set_p): Adjust call to note_stores.
(reg_set_last): Likewise.
@@ -4110,7 +4110,7 @@ Wed Oct 27 12:33:40 1999 Mark Mitchell <mark@codesourcery.com>
(prescan_loop): Adjust calls to note_stores.
(strength_reduce): Likewise.
(check_dbra_loop): Likewise.
- * regmove.c (flags_set_1): Take additional paramter.
+ * regmove.c (flags_set_1): Take additional parameter.
(mark_flags_life_zones): Adjust calls to note_stores.
* reload1.c (mark_not_eliminable): Take additional parameter.
(forget_old_reloads_1): Likewise.
@@ -4124,7 +4124,7 @@ Wed Oct 27 12:33:40 1999 Mark Mitchell <mark@codesourcery.com>
(reload_cse_regs_1): Likewise.
(reload_cse_record_set): Adjust calls to reload_cse_invalidate_rtx.
(reload_combine): Adjust calls to note_stores.
- * resource.c (update_live_status): Take additional paramter.
+ * resource.c (update_live_status): Take additional parameter.
(mark_target_live_regs): Adjust calls to note_stores.
* stupid.c (find_clobbered_regs): Take additional parameter.
(stupid_life_analysis): Adjust calls to note_stores.
@@ -5833,7 +5833,7 @@ Thu Oct 7 23:06:50 1999 Richard Henderson <rth@cygnus.com>
Thu Oct 7 22:53:00 1999 Franz Sirl <Franz.Sirl-kernel@lauterbach.com>
Mark Mitchell <mark@codesourcery.com>
- * tree.c (make_lang_type_fn): New funtion pointer.
+ * tree.c (make_lang_type_fn): New function pointer.
(make_lang_type): Call it.
* tree.h (make_lang_type): Declare.
(make_lang_type_fn): Likewise.
@@ -8622,7 +8622,7 @@ Tue Sep 7 00:47:52 1999 Mark Mitchell <mark@codesourcery.com>
* except.c (mark_func_eh_entry): New function.
(mark_eh_node): Mark false_label and rethrow_label.
(init_eh): Add more GC roots.
- * function.c (free_after_compilation): Take decl as a paramter.
+ * function.c (free_after_compilation): Take decl as a parameter.
Call free_stmt_status.
(mark_function_state): Don't assume x_parm_reg_stack_loc is
non-NULL.
diff --git a/gcc/ChangeLog.4 b/gcc/ChangeLog.4
index 1e5f4f44f33..36bc937bd7e 100644
--- a/gcc/ChangeLog.4
+++ b/gcc/ChangeLog.4
@@ -14340,7 +14340,7 @@ Wed Jul 12 13:15:16 2000 Marc Espie <espie@openbsd.org>
* cpphash.c: (struct macro_info, alloc_macro, free_macro,
struct toklist_dummy): New.
(cpp_free_definition): Free macros with free_macro.
- (count_params): Don't save paramter spellings. Save macro
+ (count_params): Don't save parameter spellings. Save macro
information in a struct macro_info.
(parse_define): Don't allocate a token list.
(save_expansion): Allocate the macro's token list, and
diff --git a/gcc/ChangeLog.5 b/gcc/ChangeLog.5
index 9109d0015e7..f2e578dcd48 100644
--- a/gcc/ChangeLog.5
+++ b/gcc/ChangeLog.5
@@ -6191,7 +6191,7 @@ Tue Apr 10 17:45:50 2001 Richard Kenner <kenner@vlsi1.ultra.nyu.edu>
(store_ops_ok): Verfies registers expressions are valid in a block.
(find_moveable_store): Look for moveable stores in a pattern.
(compute_store_table): Find stores in a function worth moving, maybe.
- (load_kills_store): Check dependance of a load and store.
+ (load_kills_store): Check dependence of a load and store.
(find_loads): Find any loads in a pattern.
(store_killed_in_insn): Check if a store is killed in an insn.
(store_killed_after): Check is store killed after an insn in a block.
diff --git a/gcc/FSFChangeLog.10 b/gcc/FSFChangeLog.10
index fa4494702ea..10cc3092f86 100644
--- a/gcc/FSFChangeLog.10
+++ b/gcc/FSFChangeLog.10
@@ -4259,7 +4259,7 @@ Wed Nov 29 14:06:13 1995 Jim Wilson <wilson@cygnus.com>
Wed Nov 29 13:59:58 1995 J"orn Rennecke (amylaar@meolyon.hanse.de)
- * c-decl.c (duplicate_decls): Add new paramter different_binding_level.
+ * c-decl.c (duplicate_decls): Add new parameter different_binding_level.
Lots of changes to use new new parameter.
(pushdecl): Delete variable declared_global. New variable
different_binding_level and code to set it. Move extern/static
@@ -9913,7 +9913,7 @@ Fri Mar 10 05:50:11 1995 Oliver Kellogg (Oliver.Kellogg@RST13.DASA.DBMAIL.d400
* 1750a.c (sectname): Reverse Init and Normal.
(print_operand_address, case PLUS): Add case for LABEL_REF.
- (print_operand_address, case LABEL_REF): Split fom SYMBOL_REF.
+ (print_operand_address, case LABEL_REF): Split from SYMBOL_REF.
(print_operand_address, case CODE_LABEL): New case.
(ASM_FILE_END): Delete.
* 1750a.h (FUNCTION_EPILOGUE): Restore stack before freeing local vars.
diff --git a/gcc/FSFChangeLog.11 b/gcc/FSFChangeLog.11
index 11104853279..38de90cfe2e 100644
--- a/gcc/FSFChangeLog.11
+++ b/gcc/FSFChangeLog.11
@@ -5434,7 +5434,7 @@ Thu Jun 5 13:40:33 1997 Mike Meissner <meissner@cygnus.com>
(life_analysis): Don't allocate the space to hold to vector of
regsets here.
(init_regset_vector): Add pointer parameter and delete space
- paramter. Use OBSTACK_ALLOC_REG_SET to allocate. Change callers.
+ parameter. Use OBSTACK_ALLOC_REG_SET to allocate. Change callers.
(propagate_block): Use ALLOCA_REG_SET instead of bare alloca.
* sched.c (schedule_block): Fix typo in yesterday's changes.
@@ -8809,7 +8809,7 @@ Sun Nov 24 17:06:58 1996 Bernd Schmidt (crux@Pool.Informatik.RWTH-Aachen.DE)
Sun Nov 24 16:37:18 1996 Dave Love <d.love@dl.ac.uk>
* configure (objc_thread_file): Set conditionally in each case so
- may be overidden with `--enable-objcthreads=posix'.
+ may be overridden with `--enable-objcthreads=posix'.
Change GNU/Linux default to `single'.
Fri Nov 22 17:53:15 1996 Jason Merrill <jason@yorick.cygnus.com>
diff --git a/gcc/alias.c b/gcc/alias.c
index 2581b2acb1d..68b80b8d6d3 100644
--- a/gcc/alias.c
+++ b/gcc/alias.c
@@ -341,7 +341,7 @@ objects_must_conflict_p (t1, t2)
/* T is an expression with pointer type. Find the DECL on which this
expression is based. (For example, in `a[i]' this would be `a'.)
If there is no such DECL, or a unique decl cannot be determined,
- NULL_TREE is retured. */
+ NULL_TREE is returned. */
static tree
find_base_decl (t)
@@ -1253,7 +1253,7 @@ find_base_term (x)
rtx tmp1 = XEXP (x, 0);
rtx tmp2 = XEXP (x, 1);
- /* This is a litle bit tricky since we have to determine which of
+ /* This is a little bit tricky since we have to determine which of
the two operands represents the real base address. Otherwise this
routine may return the index register instead of the base register.
@@ -1816,7 +1816,7 @@ true_dependence (mem, mem_mode, x, varies)
if (aliases_everything_p (x))
return 1;
- /* We cannot use aliases_everyting_p to test MEM, since we must look
+ /* We cannot use aliases_everything_p to test MEM, since we must look
at MEM_MODE, rather than GET_MODE (MEM). */
if (mem_mode == QImode || GET_CODE (mem_addr) == AND)
return 1;
@@ -1831,7 +1831,7 @@ true_dependence (mem, mem_mode, x, varies)
}
/* Canonical true dependence: X is read after store in MEM takes place.
- Variant of true_dependece which assumes MEM has already been
+ Variant of true_dependence which assumes MEM has already been
canonicalized (hence we no longer do that here).
The mem_addr argument has been added, since true_dependence computed
this value prior to canonicalizing. */
@@ -1873,7 +1873,7 @@ canon_true_dependence (mem, mem_mode, mem_addr, x, varies)
if (aliases_everything_p (x))
return 1;
- /* We cannot use aliases_everyting_p to test MEM, since we must look
+ /* We cannot use aliases_everything_p to test MEM, since we must look
at MEM_MODE, rather than GET_MODE (MEM). */
if (mem_mode == QImode || GET_CODE (mem_addr) == AND)
return 1;
@@ -2231,7 +2231,7 @@ init_alias_analysis ()
start counting from zero each iteration of the loop. */
unique_id = 0;
- /* We're at the start of the funtion each iteration through the
+ /* We're at the start of the function each iteration through the
loop, so we're copying arguments. */
copying_arguments = 1;
@@ -2273,7 +2273,7 @@ init_alias_analysis ()
rtx note, set;
#if defined (HAVE_prologue) || defined (HAVE_epilogue)
- /* The prologue/epilouge insns are not threaded onto the
+ /* The prologue/epilogue insns are not threaded onto the
insn chain until after reload has completed. Thus,
there is no sense wasting time checking if INSN is in
the prologue/epilogue until after reload has completed. */
diff --git a/gcc/attribs.c b/gcc/attribs.c
index 3f8edcebd51..a20ff35b36c 100644
--- a/gcc/attribs.c
+++ b/gcc/attribs.c
@@ -252,7 +252,7 @@ init_attributes ()
a decl attribute to the declaration rather than to its type). If
ATTR_FLAG_BUILT_IN is not set and *NODE is a DECL, then also consider
whether there might be some default attributes to apply to this DECL;
- if so, decl_attributes will be called recusrively with those attributes
+ if so, decl_attributes will be called recursively with those attributes
and ATTR_FLAG_BUILT_IN set. */
tree
diff --git a/gcc/caller-save.c b/gcc/caller-save.c
index e2d84b7f657..7c891976b39 100644
--- a/gcc/caller-save.c
+++ b/gcc/caller-save.c
@@ -406,7 +406,7 @@ save_call_clobbered_regs ()
else
save_mode [regno] = VOIDmode;
- /* Look trought all live pseudos, mark their hard registers
+ /* Look through all live pseudos, mark their hard registers
and choose proper mode for saving. */
EXECUTE_IF_SET_IN_REG_SET
(&chain->live_throughout, FIRST_PSEUDO_REGISTER, regno,
diff --git a/gcc/calls.c b/gcc/calls.c
index a0c451c42fd..710d6760d03 100644
--- a/gcc/calls.c
+++ b/gcc/calls.c
@@ -1370,7 +1370,7 @@ compute_argument_block_size (reg_parm_stack_space, args_size,
/* For accumulate outgoing args mode we don't need to align, since the frame
will be already aligned. Align to STACK_BOUNDARY in order to prevent
- backends from generating missaligned frame sizes. */
+ backends from generating misaligned frame sizes. */
if (ACCUMULATE_OUTGOING_ARGS && preferred_stack_boundary > STACK_BOUNDARY)
preferred_stack_boundary = STACK_BOUNDARY;
@@ -1387,7 +1387,7 @@ compute_argument_block_size (reg_parm_stack_space, args_size,
if (preferred_stack_boundary > 1)
{
/* We don't handle this case yet. To handle it correctly we have
- to add the delta, round and substract the delta.
+ to add the delta, round and subtract the delta.
Currently no machine description requires this support. */
if (stack_pointer_delta & (preferred_stack_boundary - 1))
abort ();
@@ -1466,7 +1466,7 @@ precompute_arguments (flags, num_actuals, args)
function call which will store arguments on the stack.
Otherwise, evaluating the parameter may clobber previous parameters
which have already been stored into the stack. (we have code to avoid
- such case by saving the ougoing stack arguments, but it results in
+ such case by saving the outgoing stack arguments, but it results in
worse code) */
for (i = 0; i < num_actuals; i++)
@@ -2487,7 +2487,7 @@ expand_call (exp, target, ignore)
initialize_argument_information has ordered the array for the
order to be pushed, and we must remember this when reconstructing
- the original argument orde. */
+ the original argument order. */
if (PUSH_ARGS_REVERSED)
{
@@ -2612,7 +2612,7 @@ expand_call (exp, target, ignore)
for (pass = 0; pass < 2; pass++)
{
int sibcall_failure = 0;
- /* We want to emit ay pending stack adjustments before the tail
+ /* We want to emit any pending stack adjustments before the tail
recursion "call". That way we know any adjustment after the tail
recursion call can be ignored if we indeed use the tail recursion
call expansion. */
@@ -4550,7 +4550,7 @@ store_one_arg (arg, argblock, flags, variable_size, reg_parm_stack_space)
#endif
{
if (arg->offset.constant < reg_parm_stack_space && arg->offset.var)
- error ("variable offset is passed paritially in stack and in reg");
+ error ("variable offset is passed partially in stack and in reg");
else if (arg->offset.constant < reg_parm_stack_space && arg->size.var)
error ("variable size is passed partially in stack and in reg");
else if (arg->offset.constant < reg_parm_stack_space
diff --git a/gcc/cfg.c b/gcc/cfg.c
index 83b0ff06037..6071e8dbedc 100644
--- a/gcc/cfg.c
+++ b/gcc/cfg.c
@@ -22,7 +22,7 @@ Software Foundation, 59 Temple Place - Suite 330, Boston, MA
/* This file contains low level functions to manipulate with CFG and analyze it.
All other modules should not transform the datastructure directly and use
abstraction instead. The file is supposed to be ordered bottom-up and should
- not contain any code depdendent on particular intermediate language (RTL or trees)
+ not contain any code dependent on particular intermediate language (RTL or trees)
Available functionality:
- Initialization/deallocation
diff --git a/gcc/cfganal.c b/gcc/cfganal.c
index 8615a14755e..7dd51e6c6cc 100644
--- a/gcc/cfganal.c
+++ b/gcc/cfganal.c
@@ -76,7 +76,7 @@ forwarder_block_p (bb)
|| !active_insn_p (insn));
}
-/* Return nonzero if we can reach target from src by falling trought. */
+/* Return nonzero if we can reach target from src by falling through. */
bool
can_fallthru (src, target)
basic_block src, target;
diff --git a/gcc/cfgcleanup.c b/gcc/cfgcleanup.c
index d4a929d50a7..addd84e7feb 100644
--- a/gcc/cfgcleanup.c
+++ b/gcc/cfgcleanup.c
@@ -26,7 +26,7 @@ Software Foundation, 59 Temple Place - Suite 330, Boston, MA
- Edge forwarding (edge to the forwarder block is forwarded to it's
succesor. Simplification of the branch instruction is performed by
underlying infrastructure so branch can be converted to simplejump or
- elliminated).
+ eliminated).
- Cross jumping (tail merging)
- Conditional jump-around-simplejump simplification
- Basic block merging. */
diff --git a/gcc/cfgrtl.c b/gcc/cfgrtl.c
index 16fca3919aa..2987a506618 100644
--- a/gcc/cfgrtl.c
+++ b/gcc/cfgrtl.c
@@ -1919,7 +1919,7 @@ purge_dead_edges (bb)
/* Search all basic blocks for potentionally dead edges and purge them.
- Return true ifif some edge has been elliminated.
+ Return true iff some edge has been eliminated.
*/
bool
diff --git a/gcc/config/alpha/alpha.c b/gcc/config/alpha/alpha.c
index 4affac34edc..511db5999b4 100644
--- a/gcc/config/alpha/alpha.c
+++ b/gcc/config/alpha/alpha.c
@@ -7618,7 +7618,7 @@ alpha_align_insns (insns, max_align, next_group, next_nop)
}
}
-/* Machine dependant reorg pass. */
+/* Machine dependent reorg pass. */
void
alpha_reorg (insns)
diff --git a/gcc/config/alpha/alpha.md b/gcc/config/alpha/alpha.md
index 25eb09e7ba0..8594c82ce86 100644
--- a/gcc/config/alpha/alpha.md
+++ b/gcc/config/alpha/alpha.md
@@ -84,7 +84,7 @@ fadd,fmul,fcpys,fdiv,fsqrt,misc,mvi,ftoi,itof,multi"
[(set_attr "type" "multi")])
;; Define the operand size an insn operates on. Used primarily by mul
-;; and div operations that have size dependant timings.
+;; and div operations that have size dependent timings.
(define_attr "opsize" "si,di,udi"
(const_string "di"))
@@ -284,13 +284,13 @@ fadd,fmul,fcpys,fdiv,fsqrt,misc,mvi,ftoi,itof,multi"
(and (eq_attr "cpu" "ev5")
(and (eq_attr "type" "fdiv")
(eq_attr "opsize" "si")))
- 15 15) ; 15 to 31 data dependant
+ 15 15) ; 15 to 31 data dependent
(define_function_unit "fdiv" 1 0
(and (eq_attr "cpu" "ev5")
(and (eq_attr "type" "fdiv")
(eq_attr "opsize" "di")))
- 22 22) ; 22 to 60 data dependant
+ 22 22) ; 22 to 60 data dependent
;; EV6 scheduling. EV6 can issue 4 insns per clock.
;;
@@ -433,7 +433,7 @@ fadd,fmul,fcpys,fdiv,fsqrt,misc,mvi,ftoi,itof,multi"
;; sign-extend.
;; Handle 32-64 bit extension from memory to a floating point register
-;; specially, since this ocurrs frequently in int->double conversions.
+;; specially, since this occurs frequently in int->double conversions.
;;
;; Note that while we must retain the =f case in the insn for reload's
;; benefit, it should be eliminated after reload, so we should never emit
@@ -6643,7 +6643,7 @@ fadd,fmul,fcpys,fdiv,fsqrt,misc,mvi,ftoi,itof,multi"
"trapb"
[(set_attr "type" "misc")])
-;; No-op instructions used by machine-dependant reorg to preserve
+;; No-op instructions used by machine-dependent reorg to preserve
;; alignment for instruction issue.
;; The Unicos/Mk assembler does not support these opcodes.
diff --git a/gcc/config/c4x/c4x.h b/gcc/config/c4x/c4x.h
index 8b5025c536e..924642a3872 100644
--- a/gcc/config/c4x/c4x.h
+++ b/gcc/config/c4x/c4x.h
@@ -1555,7 +1555,7 @@ CUMULATIVE_ARGS;
The problem is a subtle one and deals with the manner in which the
negative condition (N) flag is used on the C4x. This flag does not
reflect the status of the actual result but of the ideal result had
- no overflow occured (when considering signed operands).
+ no overflow occurred (when considering signed operands).
For example, 0x7fffffff + 1 => 0x80000000 Z=0 V=1 N=0 C=0. Here
the flags reflect the untruncated result, not the actual result.
@@ -1591,7 +1591,7 @@ CUMULATIVE_ARGS;
To handle the problem where the N flag is set differently whenever
there is an overflow we use a different CC mode, CC_NOOVmode which
says that the CC reflects the comparison of the result against zero
- if no overflow occured.
+ if no overflow occurred.
For example,
diff --git a/gcc/config/cris/cris.h b/gcc/config/cris/cris.h
index 31d89718c05..2857788a968 100644
--- a/gcc/config/cris/cris.h
+++ b/gcc/config/cris/cris.h
@@ -122,7 +122,7 @@ extern const char *cris_elinux_stacksize_str;
Note that for -melinux and -mlinux, command-line -isystem options are
emitted both before and after the synthesized one. We can't remove all
of them: a %{<isystem} will only remove the first one and %{<isystem*}
- will not do TRT. Those extra occurences are harmless anyway. */
+ will not do TRT. Those extra occurrences are harmless anyway. */
#define CPP_SPEC \
"-$ -D__CRIS_ABI_version=2\
%{mtune=*:-D__tune_%* %{mtune=v*:-D__CRIS_arch_tune=%*}}\
@@ -199,7 +199,7 @@ extern const char *cris_elinux_stacksize_str;
are linked in (multilibbing). The somewhat cryptic -rpath-link pair is
to avoid *only* picking up the linux multilib subdir from the "-B./"
option during build, while still giving it preference. We'd need some
- %s-variant that checked for existance of some specific file. */
+ %s-variant that checked for existence of some specific file. */
/* Override previous definitions (svr4.h). */
#undef LINK_SPEC
#define LINK_SPEC \
@@ -294,7 +294,7 @@ extern int target_flags;
#define TARGET_MASK_DATA_ALIGN 128
#define TARGET_DATA_ALIGN (target_flags & TARGET_MASK_DATA_ALIGN)
-/* If not to omit funtion prologue and epilogue. */
+/* If not to omit function prologue and epilogue. */
#define TARGET_MASK_PROLOGUE_EPILOGUE 256
#define TARGET_PROLOGUE_EPILOGUE (target_flags & TARGET_MASK_PROLOGUE_EPILOGUE)
diff --git a/gcc/config/cris/cris.md b/gcc/config/cris/cris.md
index 3df8aaabef3..dedf8a84e58 100644
--- a/gcc/config/cris/cris.md
+++ b/gcc/config/cris/cris.md
@@ -2635,7 +2635,7 @@
;; second operand, and the third operand is -256 or -65536, we can use
;; CLEAR instead. Or, if the first operand is a register, and the third
;; operand is 255 or 65535, we can zero_extend.
-;; GCC isnt smart enough to recognize these cases (yet), and they seem
+;; GCC isn't smart enough to recognize these cases (yet), and they seem
;; to be common enough to be worthwhile.
;; FIXME: This should be made obsolete.
diff --git a/gcc/config/i370/i370.md b/gcc/config/i370/i370.md
index c0d05e6e791..b6da211b178 100644
--- a/gcc/config/i370/i370.md
+++ b/gcc/config/i370/i370.md
@@ -1964,7 +1964,7 @@ check_label_emit ();
"*
{
check_label_emit ();
- CC_STATUS_INIT; /* add assumes CC but LA doesnt set CC */
+ CC_STATUS_INIT; /* add assumes CC but LA doesn't set CC */
mvs_check_page (0, 4, 0);
return \"LA %0,%c2(,%1)\";
}"
@@ -1983,7 +1983,7 @@ check_label_emit ();
check_label_emit ();
if ((unsigned) INTVAL (operands[2]) < 4096)
{
- CC_STATUS_INIT; /* add assumes CC but LA doesnt set CC */
+ CC_STATUS_INIT; /* add assumes CC but LA doesn't set CC */
mvs_check_page (0, 4, 0);
return \"LA %0,%c2(,%1)\";
}
@@ -2023,7 +2023,7 @@ check_label_emit ();
{
if (INTVAL (operands[2]) == -1)
{
- CC_STATUS_INIT; /* add assumes CC but BCTR doesnt set CC */
+ CC_STATUS_INIT; /* add assumes CC but BCTR doesn't set CC */
mvs_check_page (0, 2, 0);
return \"BCTR %0,0\";
}
@@ -2055,7 +2055,7 @@ check_label_emit ();
{
if (INTVAL (operands[2]) == -1)
{
- CC_STATUS_INIT; /* add assumes CC but BCTR doesnt set CC */
+ CC_STATUS_INIT; /* add assumes CC but BCTR doesn't set CC */
mvs_check_page (0, 2, 0);
return \"BCTR %0,0\";
}
@@ -2080,7 +2080,7 @@ check_label_emit ();
"*
{
check_label_emit ();
- CC_STATUS_INIT; /* add assumes CC but LA doesnt set CC */
+ CC_STATUS_INIT; /* add assumes CC but LA doesn't set CC */
mvs_check_page (0, 4, 0);
if (REG_P (operands[2]))
return \"LA %0,0(%1,%2)\";
@@ -2235,7 +2235,7 @@ check_label_emit ();
}
if (operands[2] == const1_rtx)
{
- CC_STATUS_INIT; /* subtract assumes CC but BCTR doesnt set CC */
+ CC_STATUS_INIT; /* subtract assumes CC but BCTR doesn't set CC */
mvs_check_page (0, 2, 0);
return \"BCTR %0,0\";
}
@@ -2264,7 +2264,7 @@ check_label_emit ();
}
if (operands[2] == const1_rtx)
{
- CC_STATUS_INIT; /* subtract assumes CC but BCTR doesnt set CC */
+ CC_STATUS_INIT; /* subtract assumes CC but BCTR doesn't set CC */
mvs_check_page (0, 2, 0);
return \"BCTR %0,0\";
}
diff --git a/gcc/config/i386/i386.h b/gcc/config/i386/i386.h
index fda362059bf..a23644a605a 100644
--- a/gcc/config/i386/i386.h
+++ b/gcc/config/i386/i386.h
@@ -167,7 +167,7 @@ extern int target_flags;
#define TARGET_FLOAT_RETURNS_IN_80387 (target_flags & MASK_FLOAT_RETURNS)
/* Long double is 128bit instead of 96bit, even when only 80bits are used.
- This mode wastes cache, but avoid missaligned data accesses and simplifies
+ This mode wastes cache, but avoid misaligned data accesses and simplifies
address calculations. */
#define TARGET_128BIT_LONG_DOUBLE (target_flags & MASK_128BIT_LONG_DOUBLE)
diff --git a/gcc/config/i386/i386.md b/gcc/config/i386/i386.md
index 55175ca1659..5479fc19b85 100644
--- a/gcc/config/i386/i386.md
+++ b/gcc/config/i386/i386.md
@@ -2363,7 +2363,7 @@
(set_attr "mode" "DI")])
;; Convert impossible pushes of immediate to existing instructions.
-;; First try to get scratch register and go trought it. In case this
+;; First try to get scratch register and go through it. In case this
;; fails, push sign extended lower part first and then overwrite
;; upper part by 32bit move.
(define_peephole2
@@ -2575,7 +2575,7 @@
(set_attr "mode" "DI")])
;; Convert impossible stores of immediate to existing instructions.
-;; First try to get scratch register and go trought it. In case this
+;; First try to get scratch register and go through it. In case this
;; fails, move by 32bit parts.
(define_peephole2
[(match_scratch:DI 2 "r")
@@ -8106,7 +8106,7 @@
(const_int 0)))]
"TARGET_64BIT
&& ix86_match_ccmode (insn, CCNOmode)
- /* The code bellow cannot deal with constants outside HOST_WIDE_INT. */
+ /* The code below cannot deal with constants outside HOST_WIDE_INT. */
&& INTVAL (operands[1]) + INTVAL (operands[2]) < HOST_BITS_PER_WIDE_INT
/* Ensure that resulting mask is zero or sign extended operand. */
&& (INTVAL (operands[1]) + INTVAL (operands[2]) <= 32
@@ -16198,7 +16198,7 @@
;; Misc patterns (?)
-;; This pattern exists to put a dependancy on all ebp-based memory accesses.
+;; This pattern exists to put a dependency on all ebp-based memory accesses.
;; Otherwise there will be nothing to keep
;;
;; [(set (reg ebp) (reg esp))]
@@ -16904,7 +16904,7 @@
;; "and imm, reg" if reg dies. The "and" form is also shorter (one
;; byte opcode instead of two, have a short form for byte operands),
;; so do it for other CPUs as well. Given that the value was dead,
-;; this should not create any new dependancies. Pass on the sub-word
+;; this should not create any new dependencies. Pass on the sub-word
;; versions if we're concerned about partial register stalls.
(define_peephole2
@@ -17147,12 +17147,12 @@
;; The ESP adjustments can be done by the push and pop instructions. Resulting
;; code is shorter, since push is only 1 byte, while add imm, %esp 3 bytes. On
;; many CPUs it is also faster, since special hardware to avoid esp
-;; dependancies is present.
+;; dependencies is present.
;; While some of these converisons may be done using splitters, we use peepholes
;; in order to allow combine_stack_adjustments pass to see nonobfuscated RTL.
-;; Convert prologue esp substractions to push.
+;; Convert prologue esp subtractions to push.
;; We need register to push. In order to keep verify_flow_info happy we have
;; two choices
;; - use scratch and clobber it in order to avoid dependencies
@@ -17184,7 +17184,7 @@
(parallel [(set (mem:SI (pre_dec:SI (reg:SI 7))) (match_dup 0))
(clobber (mem:BLK (scratch)))])])
-;; Convert esp substractions to push.
+;; Convert esp subtractions to push.
(define_peephole2
[(match_scratch:SI 0 "r")
(parallel [(set (reg:SI 7) (plus:SI (reg:SI 7) (const_int -4)))
@@ -17362,7 +17362,7 @@
(parallel [(set (mem:DI (pre_dec:DI (reg:DI 7))) (match_dup 0))
(clobber (mem:BLK (scratch)))])])
-;; Convert esp substractions to push.
+;; Convert esp subtractions to push.
(define_peephole2
[(match_scratch:DI 0 "r")
(parallel [(set (reg:DI 7) (plus:DI (reg:DI 7) (const_int -8)))
diff --git a/gcc/config/i386/xm-djgpp.h b/gcc/config/i386/xm-djgpp.h
index 2e5260e3e23..b8367acc912 100644
--- a/gcc/config/i386/xm-djgpp.h
+++ b/gcc/config/i386/xm-djgpp.h
@@ -30,7 +30,7 @@ Boston, MA 02111-1307, USA. */
/* Allow test for DOS drive names. */
#define HAVE_DOS_BASED_FILE_SYSTEM
-/* System dependant initialization for collect2
+/* System dependent initialization for collect2
to tell system() to act like Unix. */
#define COLLECT2_HOST_INITIALIZATION \
do { __system_flags |= (__system_allow_multiple_cmds \
diff --git a/gcc/config/ia64/ia64.c b/gcc/config/ia64/ia64.c
index aef598bbf8e..87c35e76f2f 100644
--- a/gcc/config/ia64/ia64.c
+++ b/gcc/config/ia64/ia64.c
@@ -1052,7 +1052,7 @@ ia64_split_timode (out, in, scratch)
We got into problems in the first place by allowing a construct like
(subreg:TF (reg:TI)), which we got from a union containing a long double.
- This solution attempts to prevent this situation from ocurring. When
+ This solution attempts to prevent this situation from occurring. When
we see something like the above, we spill the inner register to memory. */
rtx
diff --git a/gcc/config/m68hc11/m68hc11.c b/gcc/config/m68hc11/m68hc11.c
index 00d27e025a4..bb561255097 100644
--- a/gcc/config/m68hc11/m68hc11.c
+++ b/gcc/config/m68hc11/m68hc11.c
@@ -4620,7 +4620,7 @@ m68hc11_z_replacement (insn)
}
- /* Replace all occurence of Z by replace_reg.
+ /* Replace all occurrence of Z by replace_reg.
Stop when the last instruction to replace is reached.
Also stop when we detect a change in the flow (but it's not
necessary; just safeguard). */
diff --git a/gcc/config/m68k/m68k.md b/gcc/config/m68k/m68k.md
index b2463f1d608..41cf9b20468 100644
--- a/gcc/config/m68k/m68k.md
+++ b/gcc/config/m68k/m68k.md
@@ -7277,7 +7277,7 @@
return \"bsr.l %0\";
#else
/* The ',a1' is a dummy argument telling the Sun assembler we want PIC,
- GAS just plain ignores it. FIXME: not anymore, gas doesnt! */
+ GAS just plain ignores it. FIXME: not anymore, gas doesn't! */
return \"jbsr %0,a1\";
#endif
#endif
@@ -7347,7 +7347,7 @@
return \"bsr.l %1\";
#else
/* The ',a1' is a dummy argument telling the Sun assembler we want PIC
- GAS just plain ignores it. FIXME: Not anymore, gas doesnt! */
+ GAS just plain ignores it. FIXME: Not anymore, gas doesn't! */
return \"jbsr %1,a1\";
#endif
#endif
diff --git a/gcc/config/mcore/mcore.h b/gcc/config/mcore/mcore.h
index 0b66920ad9c..1795a695bd8 100644
--- a/gcc/config/mcore/mcore.h
+++ b/gcc/config/mcore/mcore.h
@@ -356,7 +356,7 @@ extern int mcore_stack_increment;
#define LK_REG 15 /* overloaded on general register */
#define AP_REG 16 /* fake arg pointer register */
/* RBE: mcore.md depends on CC_REG being set to 17 */
-#define CC_REG 17 /* cant name it C_REG */
+#define CC_REG 17 /* can't name it C_REG */
#define FP_REG 18 /* fake frame pointer register */
/* Specify the registers used for certain standard purposes.
diff --git a/gcc/config/mmix/mmix.c b/gcc/config/mmix/mmix.c
index c37853128ad..737f6c7f198 100644
--- a/gcc/config/mmix/mmix.c
+++ b/gcc/config/mmix/mmix.c
@@ -2505,7 +2505,7 @@ mmix_dbx_register_number (regno)
return regno >= 224 ? (regno - 224) : (regno + 48);
}
-/* End of target macro support funtions.
+/* End of target macro support functions.
Now MMIX's own functions. First the exported ones. */
diff --git a/gcc/config/ns32k/ns32k.h b/gcc/config/ns32k/ns32k.h
index 373f78f7fbc..fb2cd4d908d 100644
--- a/gcc/config/ns32k/ns32k.h
+++ b/gcc/config/ns32k/ns32k.h
@@ -855,7 +855,7 @@ __transfer_from_trampoline () \
because registers of CLASS are needed for spill registers.
The default definition won't do because class LONG_FLOAT_REG0 has two
- registers which are always acessed as a pair */
+ registers which are always accessed as a pair */
#define CLASS_LIKELY_SPILLED_P(CLASS) \
(reg_class_size[(int) (CLASS)] == 1 || (CLASS) == LONG_FLOAT_REG0)
diff --git a/gcc/config/ns32k/ns32k.md b/gcc/config/ns32k/ns32k.md
index af1b60fcb70..f7452ac627d 100644
--- a/gcc/config/ns32k/ns32k.md
+++ b/gcc/config/ns32k/ns32k.md
@@ -386,7 +386,7 @@
}
else if (GET_CODE (operands[1]) == CONST && ! flag_pic)
{
- /* Must contain symbols so we don`t know how big it is. In
+ /* Must contain symbols so we don't know how big it is. In
* that case addr might lead to overflow. For PIC symbolic
* address loads always have to be done with addr.
*/
diff --git a/gcc/config/rs6000/rs6000.c b/gcc/config/rs6000/rs6000.c
index f10cef5aee8..56317afee59 100644
--- a/gcc/config/rs6000/rs6000.c
+++ b/gcc/config/rs6000/rs6000.c
@@ -8318,7 +8318,7 @@ rs6000_select_section (decl, reloc)
RELOC indicates whether the initial value of EXP requires
link-time relocations. If you do not define this macro, GCC will use
the symbol name prefixed by `.' as the section name. Note - this
- macro can now be called for unitialised data items as well as
+ macro can now be called for uninitialized data items as well as
initialised data and functions. */
void
diff --git a/gcc/config/rs6000/sysv4.h b/gcc/config/rs6000/sysv4.h
index 882df2f4b79..a6f79a1dc50 100644
--- a/gcc/config/rs6000/sysv4.h
+++ b/gcc/config/rs6000/sysv4.h
@@ -582,7 +582,7 @@ fini_section () \
RELOC indicates whether the initial value of EXP requires
link-time relocations. If you do not define this macro, GCC will use
the symbol name prefixed by `.' as the section name. Note - this
- macro can now be called for unitialised data items as well as
+ macro can now be called for uninitialized data items as well as
initialised data and functions. */
/* Override elfos.h definition. */
diff --git a/gcc/config/sh/sh.md b/gcc/config/sh/sh.md
index 69857c32024..fd6a7604813 100644
--- a/gcc/config/sh/sh.md
+++ b/gcc/config/sh/sh.md
@@ -406,7 +406,7 @@
[(const_int 1)])
;; arith3 insns are always pairable at the start, but not inecessarily at
-;; the end; however, there doesn;t seem to be a way to express that.
+;; the end; however, there doesn't seem to be a way to express that.
(define_function_unit "single_issue" 1 0
(and (eq_attr "issues" "2")
(eq_attr "type" "arith3"))
diff --git a/gcc/cppmacro.c b/gcc/cppmacro.c
index 9390cbce3b5..4fb2df91780 100644
--- a/gcc/cppmacro.c
+++ b/gcc/cppmacro.c
@@ -1162,7 +1162,7 @@ _cpp_free_definition (h)
}
/* Save parameter NODE to the parameter list of macro MACRO. Returns
- zero on success, non-zero if the paramter is a duplicate. */
+ zero on success, non-zero if the parameter is a duplicate. */
static int
save_parameter (pfile, macro, node)
cpp_reader *pfile;
diff --git a/gcc/fold-const.c b/gcc/fold-const.c
index 07184b937ce..05be225aeeb 100644
--- a/gcc/fold-const.c
+++ b/gcc/fold-const.c
@@ -4662,7 +4662,7 @@ extract_muldiv (t, c, code, wide_type)
multiple of the other, in which case we replace this with either an
operation or CODE or TCODE.
- If we have an unsigned type that is not a sizetype, we canot do
+ If we have an unsigned type that is not a sizetype, we cannot do
this since it will change the result if the original computation
overflowed. */
if ((! TREE_UNSIGNED (ctype)
diff --git a/gcc/ifcvt.c b/gcc/ifcvt.c
index d969104000c..d21b3fab81d 100644
--- a/gcc/ifcvt.c
+++ b/gcc/ifcvt.c
@@ -2532,7 +2532,7 @@ dead_or_predicable (test_bb, merge_bb, other_bb, new_dest, reversep)
/* ??? Even non-trapping memories such as stack frame
references must be avoided. For stores, we collect
no lifetime info; for reads, we'd have to assert
- true_dependance false against every store in the
+ true_dependence false against every store in the
TEST range. */
if (for_each_rtx (&PATTERN (insn), find_memory, NULL))
return FALSE;
diff --git a/gcc/local-alloc.c b/gcc/local-alloc.c
index 7cee3f5e456..7de721e8f09 100644
--- a/gcc/local-alloc.c
+++ b/gcc/local-alloc.c
@@ -79,7 +79,7 @@ Software Foundation, 59 Temple Place - Suite 330, Boston, MA
static int next_qty;
-/* Information we maitain about each quantity. */
+/* Information we maintain about each quantity. */
struct qty
{
/* The number of refs to quantity Q. */
diff --git a/gcc/profile.c b/gcc/profile.c
index bda2dc5b467..4bf4ea7e5e0 100644
--- a/gcc/profile.c
+++ b/gcc/profile.c
@@ -768,7 +768,7 @@ branch_prob ()
}
}
}
- /* Emit fake loopback edge for EXIT block to maitain compatibility with
+ /* Emit fake loopback edge for EXIT block to maintain compatibility with
old gcov format. */
__write_long (1, bbg_file, 4);
__write_long (0, bbg_file, 4);
diff --git a/gcc/sched-int.h b/gcc/sched-int.h
index 298a94ccadf..2836aef11e4 100644
--- a/gcc/sched-int.h
+++ b/gcc/sched-int.h
@@ -203,7 +203,7 @@ struct haifa_insn_data
/* Some insns (e.g. call) are not allowed to move across blocks. */
unsigned int cant_move : 1;
- /* Set if there's DEF-USE dependance between some speculatively
+ /* Set if there's DEF-USE dependence between some speculatively
moved load insn and this one. */
unsigned int fed_by_spec_load : 1;
unsigned int is_load_insn : 1;
diff --git a/gcc/toplev.c b/gcc/toplev.c
index 11d19e04baa..ad23683f45e 100644
--- a/gcc/toplev.c
+++ b/gcc/toplev.c
@@ -2756,7 +2756,7 @@ rest_of_compilation (decl)
cleanup_cfg (CLEANUP_PRE_SIBCALL | CLEANUP_PRE_LOOP);
optimize = saved_optimize;
- /* CFG is no longer maitained up-to-date. */
+ /* CFG is no longer maintained up-to-date. */
free_bb_for_insn ();
}
@@ -2867,7 +2867,7 @@ rest_of_compilation (decl)
find_basic_blocks (insns, max_reg_num (), rtl_dump_file);
cleanup_cfg ((optimize ? CLEANUP_EXPENSIVE : 0) | CLEANUP_PRE_LOOP);
- /* CFG is no longer maitained up-to-date. */
+ /* CFG is no longer maintained up-to-date. */
free_bb_for_insn ();
copy_loop_headers (insns);
purge_line_number_notes (insns);
@@ -2946,7 +2946,7 @@ rest_of_compilation (decl)
timevar_pop (TV_FROM_SSA);
ggc_collect ();
- /* CFG is no longer maitained up-to-date. */
+ /* CFG is no longer maintained up-to-date. */
free_bb_for_insn ();
}
@@ -2965,7 +2965,7 @@ rest_of_compilation (decl)
if_convert (0);
timevar_pop (TV_IFCVT);
- /* CFG is no longer maitained up-to-date. */
+ /* CFG is no longer maintained up-to-date. */
free_bb_for_insn ();
/* Try to identify useless null pointer tests and delete them. */
if (flag_delete_null_pointer_checks)
@@ -3016,7 +3016,7 @@ rest_of_compilation (decl)
find_basic_blocks (insns, max_reg_num (), rtl_dump_file);
cleanup_cfg (CLEANUP_EXPENSIVE | CLEANUP_PRE_LOOP);
timevar_pop (TV_JUMP);
- /* CFG is no longer maitained up-to-date. */
+ /* CFG is no longer maintained up-to-date. */
free_bb_for_insn ();
}
@@ -3033,7 +3033,7 @@ rest_of_compilation (decl)
cleanup_cfg (CLEANUP_EXPENSIVE | CLEANUP_PRE_LOOP);
delete_null_pointer_checks (insns);
- /* CFG is no longer maitained up-to-date. */
+ /* CFG is no longer maintained up-to-date. */
free_bb_for_insn ();
timevar_pop (TV_JUMP);
}
@@ -3073,7 +3073,7 @@ rest_of_compilation (decl)
save_cfj = flag_cse_follow_jumps;
flag_cse_skip_blocks = flag_cse_follow_jumps = 0;
- /* CFG is no longer maitained up-to-date. */
+ /* CFG is no longer maintained up-to-date. */
free_bb_for_insn ();
/* If -fexpensive-optimizations, re-run CSE to clean up things done
by gcse. */
@@ -3096,7 +3096,7 @@ rest_of_compilation (decl)
delete_trivially_dead_insns (insns, max_reg_num (), 0);
find_basic_blocks (insns, max_reg_num (), rtl_dump_file);
cleanup_cfg (CLEANUP_EXPENSIVE | CLEANUP_PRE_LOOP);
- /* CFG is no longer maitained up-to-date. */
+ /* CFG is no longer maintained up-to-date. */
free_bb_for_insn ();
timevar_pop (TV_JUMP);
@@ -3185,7 +3185,7 @@ rest_of_compilation (decl)
timevar_pop (TV_JUMP);
- /* CFG is no longer maitained up-to-date. */
+ /* CFG is no longer maintained up-to-date. */
free_bb_for_insn ();
reg_scan (insns, max_reg_num (), 0);
tem = cse_main (insns, max_reg_num (), 1, rtl_dump_file);
@@ -3196,7 +3196,7 @@ rest_of_compilation (decl)
rebuild_jump_labels (insns);
find_basic_blocks (insns, max_reg_num (), rtl_dump_file);
cleanup_cfg (CLEANUP_EXPENSIVE);
- /* CFG is no longer maitained up-to-date. */
+ /* CFG is no longer maintained up-to-date. */
free_bb_for_insn ();
timevar_pop (TV_JUMP);
}
@@ -3636,7 +3636,7 @@ rest_of_compilation (decl)
}
compute_alignments ();
- /* CFG is no longer maitained up-to-date. */
+ /* CFG is no longer maintained up-to-date. */
free_bb_for_insn ();
/* If a machine dependent reorganization is needed, call it. */
OpenPOWER on IntegriCloud
diff --git a/gcc/config/i386/i386.c b/gcc/config/i386/i386.c
index 39a55ad3f46..8fe70a2a71c 100644
--- a/gcc/config/i386/i386.c
+++ b/gcc/config/i386/i386.c
@@ -1616,7 +1616,7 @@ classify_argument (mode, type, classes, bit_offset)
mode_alignment = 128;
else if (mode == XCmode)
mode_alignment = 256;
- /* Missalignmed fields are always returned in memory. */
+ /* Misaligned fields are always returned in memory. */
if (bit_offset % mode_alignment)
return 0;
}
@@ -1678,7 +1678,7 @@ classify_argument (mode, type, classes, bit_offset)
}
/* Examine the argument and return set number of register required in each
- class. Return 0 ifif parameter should be passed in memory. */
+ class. Return 0 iff parameter should be passed in memory. */
static int
examine_argument (mode, type, in_return, int_nregs, sse_nregs)
enum machine_mode mode;
@@ -2060,7 +2060,7 @@ ix86_function_value (valtype)
return gen_rtx_REG (TYPE_MODE (valtype), VALUE_REGNO (TYPE_MODE (valtype)));
}
/* Return false ifif type is returned in memory. */
int
ix86_return_in_memory (type)
tree type;
@@ -2853,7 +2853,7 @@ incdec_operand (op, mode)
register rtx op;
enum machine_mode mode ATTRIBUTE_UNUSED;
{
- /* On Pentium4, the inc and dec operations causes extra dependancy on flag
+ /* On Pentium4, the inc and dec operations causes extra dependency on flag
registers, since carry flag is not set. */
if (TARGET_PENTIUM4 && !optimize_size)
return 0;
@@ -4174,7 +4174,7 @@ ix86_expand_epilogue (style)
}
if (frame_pointer_needed)
{
- /* Leave results in shorter depdendancy chains on CPUs that are
+ /* Leave results in shorter dependency chains on CPUs that are
able to grok it fast. */
if (TARGET_USE_LEAVE)
emit_insn (TARGET_64BIT ? gen_leave_rex64 () : gen_leave ());
@@ -9908,7 +9908,7 @@ ix86_flags_dependant (insn, dep_insn, insn_type)
if (GET_CODE (set) != REG || REGNO (set) != FLAGS_REG)
return 0;
- /* This test is true if the dependant insn reads the flags but
+ /* This test is true if the dependent insn reads the flags but
not any other potentially set register. */
if (!reg_overlap_mentioned_p (set, PATTERN (insn)))
return 0;
@@ -2060,7 +2060,7 @@ ix86_function_value (valtype)
return gen_rtx_REG (TYPE_MODE (valtype), VALUE_REGNO (TYPE_MODE (valtype)));
}
-/* Return false ifif type is returned in memory. */
+/* Return false iff type is returned in memory. */
int
ix86_return_in_memory (type)